package com.miaxis.price.domain;

import java.math.BigDecimal;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.miaxis.common.annotation.Excel;
import com.miaxis.common.core.domain.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.miaxis.common.core.domain.BaseBusinessEntity;
import lombok.Data;
/**
 * 报价对象 price_info
 *
 * @author miaxis
 * @date 2023-01-10
 */
@Data
@TableName("price_info")
@ApiModel(value = "PriceInfo", description = "报价对象 price_info")
public class PriceInfo extends BaseBusinessEntity{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id")
    @ApiModelProperty(value = "主键")
    private Long id;

    /** 品牌 */
    @Excel(name = "品牌")
    @TableField("brand")
    @ApiModelProperty(value = "品牌")
    private String brand;

    /** 机组型号 */
    @Excel(name = "机组型号")
    @TableField("unit_model")
    @ApiModelProperty(value = "机组型号")
    private String unitModel;

    /** 机组功率(kw) */
    @Excel(name = "机组功率(kw)")
    @TableField("unit_power_kw")
    @ApiModelProperty(value = "机组功率(kw)")
    private BigDecimal unitPowerKw;

    /** 机组功率(kva) */
    @Excel(name = "机组功率(kva)")
    @TableField("unit_power_kva")
    @ApiModelProperty(value = "机组功率(kva)")
    private BigDecimal unitPowerKva;

    /** 频率(Hz) */
    @Excel(name = "频率(Hz)")
    @TableField("rate")
    @ApiModelProperty(value = "频率(Hz)")
    private Integer rate;

    /** 柴油机型号 */
    @Excel(name = "柴油机型号")
    @TableField("diesel_engine_model")
    @ApiModelProperty(value = "柴油机型号")
    private String dieselEngineModel;

    /** 转速 */
    @Excel(name = "转速")
    @TableField("speed")
    @ApiModelProperty(value = "转速")
    private Integer speed;

    /** 动力价格 */
    @Excel(name = "动力价格")
    @TableField("power_price")
    @ApiModelProperty(value = "动力价格")
    private BigDecimal powerPrice;

    /** 发电机型号 */
    @Excel(name = "发电机型号")
    @TableField("generator_model")
    @ApiModelProperty(value = "发电机型号")
    private String generatorModel;

    /** 发电机价格 */
    @Excel(name = "发电机价格")
    @TableField("generator_price")
    @ApiModelProperty(value = "发电机价格")
    private BigDecimal generatorPrice;

    /** 静音机壳价格 */
    @Excel(name = "静音机壳价格")
    @TableField("mute_price")
    @ApiModelProperty(value = "静音机壳价格")
    private BigDecimal mutePrice;

    /** 开架价格 */
    @Excel(name = "开架价格")
    @TableField("open_price")
    @ApiModelProperty(value = "开架价格")
    private BigDecimal openPrice;

    /** ATS型号 */
    @Excel(name = "ATS型号")
    @TableField("ats_model")
    @ApiModelProperty(value = "ATS型号")
    private String atsModel;

    /** ATS价格 */
    @Excel(name = "ATS价格")
    @TableField("ats_price")
    @ApiModelProperty(value = "ATS价格")
    private BigDecimal atsPrice;

    /** 电瓶型号 */
    @Excel(name = "电瓶型号")
    @TableField("battery_model")
    @ApiModelProperty(value = "电瓶型号")
    private String batteryModel;

    /** 电瓶价格 */
    @Excel(name = "电瓶价格")
    @TableField("battery_price")
    @ApiModelProperty(value = "电瓶价格")
    private BigDecimal batteryPrice;

    /** 控制器铭贝 */
    @Excel(name = "控制器铭贝")
    @TableField("controller_minbei")
    @ApiModelProperty(value = "控制器铭贝")
    private String controllerMinbei;

    /** 控制器价格 */
    @Excel(name = "控制器价格")
    @TableField("controller_price")
    @ApiModelProperty(value = "控制器价格")
    private BigDecimal controllerPrice;

    /** 合计含税成本(静音) */
    @Excel(name = "合计含税成本(静音)")
    @TableField("total_cost_mute")
    @ApiModelProperty(value = "合计含税成本(静音)")
    private BigDecimal totalCostMute;

    /** 合计含税成本(开架) */
    @Excel(name = "合计含税成本(开架)")
    @TableField("total_cost_open")
    @ApiModelProperty(value = "合计含税成本(开架)")
    private BigDecimal totalCostOpen;

    /** 静音尺寸（长） */
    @Excel(name = "静音尺寸（长）", readConverterExp = "长=")
    @TableField("mute_long")
    @ApiModelProperty(value = "静音尺寸（长）")
    private BigDecimal muteLong;

    /** 静音尺寸（宽） */
    @Excel(name = "静音尺寸（宽）", readConverterExp = "宽=")
    @TableField("mute_width")
    @ApiModelProperty(value = "静音尺寸（宽）")
    private BigDecimal muteWidth;

    /** 静音尺寸（高） */
    @Excel(name = "静音尺寸（高）", readConverterExp = "高=")
    @TableField("mute_high")
    @ApiModelProperty(value = "静音尺寸（高）")
    private BigDecimal muteHigh;

    /** 开架尺寸（长） */
    @Excel(name = "开架尺寸（长）", readConverterExp = "长=")
    @TableField("open_long")
    @ApiModelProperty(value = "开架尺寸（长）")
    private BigDecimal openLong;

    /** 开架尺寸（宽） */
    @Excel(name = "开架尺寸（宽）", readConverterExp = "宽=")
    @TableField("open_width")
    @ApiModelProperty(value = "开架尺寸（宽）")
    private BigDecimal openWidth;

    /** 开架尺寸（高） */
    @Excel(name = "开架尺寸（高）", readConverterExp = "高=")
    @TableField("open_high")
    @ApiModelProperty(value = "开架尺寸（高）")
    private BigDecimal openHigh;

    /** CKD尺寸（长） */
    @Excel(name = "CKD尺寸（长）", readConverterExp = "长=")
    @TableField("ckd_long")
    @ApiModelProperty(value = "CKD尺寸（长）")
    private BigDecimal ckdLong;

    /** CKD尺寸（宽） */
    @Excel(name = "CKD尺寸（宽）", readConverterExp = "宽=")
    @TableField("ckd_width")
    @ApiModelProperty(value = "CKD尺寸（宽）")
    private BigDecimal ckdWidth;

    /** CKD尺寸（高） */
    @Excel(name = "CKD尺寸（高）", readConverterExp = "高=")
    @TableField("ckd_high")
    @ApiModelProperty(value = "CKD尺寸（高）")
    private BigDecimal ckdHigh;

    public void setId(Long id){
        this.id = id;
    }

    public Long getId(){
        return id;
    }
    public void setBrand(String brand){
        this.brand = brand;
    }

    public String getBrand(){
        return brand;
    }
    public void setUnitModel(String unitModel){
        this.unitModel = unitModel;
    }

    public String getUnitModel(){
        return unitModel;
    }
    public void setUnitPowerKw(BigDecimal unitPowerKw){
        this.unitPowerKw = unitPowerKw;
    }

    public BigDecimal getUnitPowerKw(){
        return unitPowerKw;
    }
    public void setUnitPowerKva(BigDecimal unitPowerKva){
        this.unitPowerKva = unitPowerKva;
    }

    public BigDecimal getUnitPowerKva(){
        return unitPowerKva;
    }
    public void setRate(Integer rate){
        this.rate = rate;
    }

    public Integer getRate(){
        return rate;
    }
    public void setDieselEngineModel(String dieselEngineModel){
        this.dieselEngineModel = dieselEngineModel;
    }

    public String getDieselEngineModel(){
        return dieselEngineModel;
    }
    public void setSpeed(Integer speed){
        this.speed = speed;
    }

    public Integer getSpeed(){
        return speed;
    }
    public void setPowerPrice(BigDecimal powerPrice){
        this.powerPrice = powerPrice;
    }

    public BigDecimal getPowerPrice(){
        return powerPrice;
    }
    public void setGeneratorModel(String generatorModel){
        this.generatorModel = generatorModel;
    }

    public String getGeneratorModel(){
        return generatorModel;
    }
    public void setGeneratorPrice(BigDecimal generatorPrice){
        this.generatorPrice = generatorPrice;
    }

    public BigDecimal getGeneratorPrice(){
        return generatorPrice;
    }
    public void setMutePrice(BigDecimal mutePrice){
        this.mutePrice = mutePrice;
    }

    public BigDecimal getMutePrice(){
        return mutePrice;
    }
    public void setOpenPrice(BigDecimal openPrice){
        this.openPrice = openPrice;
    }

    public BigDecimal getOpenPrice(){
        return openPrice;
    }
    public void setAtsModel(String atsModel){
        this.atsModel = atsModel;
    }

    public String getAtsModel(){
        return atsModel;
    }
    public void setAtsPrice(BigDecimal atsPrice){
        this.atsPrice = atsPrice;
    }

    public BigDecimal getAtsPrice(){
        return atsPrice;
    }
    public void setBatteryModel(String batteryModel){
        this.batteryModel = batteryModel;
    }

    public String getBatteryModel(){
        return batteryModel;
    }
    public void setBatteryPrice(BigDecimal batteryPrice){
        this.batteryPrice = batteryPrice;
    }

    public BigDecimal getBatteryPrice(){
        return batteryPrice;
    }
    public void setControllerMinbei(String controllerMinbei){
        this.controllerMinbei = controllerMinbei;
    }

    public String getControllerMinbei(){
        return controllerMinbei;
    }
    public void setControllerPrice(BigDecimal controllerPrice){
        this.controllerPrice = controllerPrice;
    }

    public BigDecimal getControllerPrice(){
        return controllerPrice;
    }
    public void setTotalCostMute(BigDecimal totalCostMute){
        this.totalCostMute = totalCostMute;
    }

    public BigDecimal getTotalCostMute(){
        return totalCostMute;
    }
    public void setTotalCostOpen(BigDecimal totalCostOpen){
        this.totalCostOpen = totalCostOpen;
    }

    public BigDecimal getTotalCostOpen(){
        return totalCostOpen;
    }
    public void setMuteLong(BigDecimal muteLong){
        this.muteLong = muteLong;
    }

    public BigDecimal getMuteLong(){
        return muteLong;
    }
    public void setMuteWidth(BigDecimal muteWidth){
        this.muteWidth = muteWidth;
    }

    public BigDecimal getMuteWidth(){
        return muteWidth;
    }
    public void setMuteHigh(BigDecimal muteHigh){
        this.muteHigh = muteHigh;
    }

    public BigDecimal getMuteHigh(){
        return muteHigh;
    }
    public void setOpenLong(BigDecimal openLong){
        this.openLong = openLong;
    }

    public BigDecimal getOpenLong(){
        return openLong;
    }
    public void setOpenWidth(BigDecimal openWidth){
        this.openWidth = openWidth;
    }

    public BigDecimal getOpenWidth(){
        return openWidth;
    }
    public void setOpenHigh(BigDecimal openHigh){
        this.openHigh = openHigh;
    }

    public BigDecimal getOpenHigh(){
        return openHigh;
    }
    public void setCkdLong(BigDecimal ckdLong){
        this.ckdLong = ckdLong;
    }

    public BigDecimal getCkdLong(){
        return ckdLong;
    }
    public void setCkdWidth(BigDecimal ckdWidth){
        this.ckdWidth = ckdWidth;
    }

    public BigDecimal getCkdWidth(){
        return ckdWidth;
    }
    public void setCkdHigh(BigDecimal ckdHigh){
        this.ckdHigh = ckdHigh;
    }

    public BigDecimal getCkdHigh(){
        return ckdHigh;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("brand", getBrand())
            .append("unitModel", getUnitModel())
            .append("unitPowerKw", getUnitPowerKw())
            .append("unitPowerKva", getUnitPowerKva())
            .append("rate", getRate())
            .append("dieselEngineModel", getDieselEngineModel())
            .append("speed", getSpeed())
            .append("powerPrice", getPowerPrice())
            .append("generatorModel", getGeneratorModel())
            .append("generatorPrice", getGeneratorPrice())
            .append("mutePrice", getMutePrice())
            .append("openPrice", getOpenPrice())
            .append("atsModel", getAtsModel())
            .append("atsPrice", getAtsPrice())
            .append("batteryModel", getBatteryModel())
            .append("batteryPrice", getBatteryPrice())
            .append("controllerMinbei", getControllerMinbei())
            .append("controllerPrice", getControllerPrice())
            .append("totalCostMute", getTotalCostMute())
            .append("totalCostOpen", getTotalCostOpen())
            .append("muteLong", getMuteLong())
            .append("muteWidth", getMuteWidth())
            .append("muteHigh", getMuteHigh())
            .append("openLong", getOpenLong())
            .append("openWidth", getOpenWidth())
            .append("openHigh", getOpenHigh())
            .append("ckdLong", getCkdLong())
            .append("ckdWidth", getCkdWidth())
            .append("ckdHigh", getCkdHigh())
            .append("createTime", getCreateTime())
            .append("updateTime", getUpdateTime())
            .toString();
    }
}
